OC.L10N.register(
    "files_sharing",
    {
    "Uploading..." : "Laai tans op…",
    "Cancel" : "Kanseleer",
    "Add" : "Voeg Toe",
    "Share" : "Deel",
    "Create public link" : "Skep openbare skakel",
    "Pending" : "Hangend",
    "Sharing" : "Deling",
    "Public link" : "Openbare skakel",
    "Accept" : "Aanvaar",
    "Decline" : "Verwerp",
    "This share is password-protected" : "Hierdie deling word met ’n wagwoord beskerm",
    "Password" : "Wagwoord",
    "The password is wrong. Try again." : "ie wagwoord is verkeerd. Probeer weer.",
    "Proceed" : "Gaan voort",
    "No entries found in this folder" : "Geen inskrywings in hierdie vouer gevind",
    "Name" : "Naam",
    "Expiration date" : "Verval datum",
    "Reasons might be:" : "Moontlike redes is:",
    "the item was removed" : "die item is verwyder",
    "sharing is disabled" : "deling is gedeaktiveer",
    "Download" : "Laai Af",
    "Download %s" : "Laai %s Af",
    "Nothing to configure." : "niks om te  verander nie"
},
"nplurals=2; plural=(n != 1);");
